# Arborescence du dossier `template_capcut_project`

```
template_capcut_project/
├── .locked
├── Resources/
│   ├── audioAlg/
│   ├── digitalHuman/
│   │   ├── audio/
│   │   ├── bsinfo/
│   │   └── video/
│   └── videoAlg/
├── adjust_mask/
├── attachment_editing.json
├── attachment_pc_common.json
├── common_attachment/
│   ├── aigc_aigc_generate.json
│   └── attachment_script_video.json
├── draftMainWindowLayoutConfig.json
├── draft_agency_config.json
├── draft_biz_config.json
├── draft_content.json
├── draft_content.json.bak
├── draft_cover.jpg
├── draft_meta_info.json
├── draft_settings
├── matting/
├── performance_opt_info.json
├── qr_upload/
├── smart_crop/
├── subdraft/
├── template-2.tmp
└── template.tmp
```

Chaque dossier et fichier listé ci-dessus reflète la structure exacte du dossier `template_capcut_project`, y compris les sous-dossiers vides et les fichiers présents. Cette structure pourra être utilisée pour cloner et adapter la création d'un nouveau projet CapCut artificiel.
